/* dhcp4_nic.h
 *
 * Network Interface Configurator for the ISC DHCP IPv4 client library API.
 *
 *  Copyright(C) Jason Vas Dias <jvdias@redhat.com> Red Hat Inc. May 2006
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation at 
 *           http://www.fsf.org/licensing/licenses/gpl.txt
 *  and included in this software distribution as the "LICENSE" file.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */
#include <libdhcp.h>
#include <dhcp4_lease.h>
#include <nic.h>
#include <stdarg.h>

typedef struct dhcpv4_control_s DHCPv4_control;

extern
DHCPv4_control*
dhcpv4_control
(
    NLH_t                  nic_handle,
    char                  *eth_if_name,
    LIBDHCP_Capability     dhc_cap, 
    time_t                 timeout,    
    LIBDHCP_Error_Handler  error_handler,
    uint8_t                log_level,
    ... /* extra dhclient args - 
         * last arg MUST be 0.
         */
);

extern
DHCPv4_control*
dhcpv4_control_va
(
    NLH_t                  nic_handle,
    char                  *eth_if_name,
    LIBDHCP_Capability     dhc_cap, 
    time_t                 timeout,    
    LIBDHCP_Error_Handler  error_handler,
    uint8_t                log_level,
    va_list                dhclient_va
);

extern
void dhcpv4_control_free( DHCPv4_control* );

typedef
struct dhcp4_nic_s
{
    NLH_t          nh;
    NIC_t          nic;
    IPaddr_list_t  address_list;
    IProute_list_t route_list;
    IPaddr_list_t  dns_list;
    char          *search_list;
    char          *host_name;
    DHCPv4_lease  *lease;
} DHCPv4_nic;

extern
DHCPv4_nic *do_dhcpv4( DHCPv4_control * );

extern
NIC_Res_t dhcpv4_nic(NLH_t, DHCPv4_nic * );

int dhcp4_process_lease(DHCPv4_control *);

extern
void dhcp4_nic_option_handler
(   DHCPv4_option *option, 
    void *arg                 /* must be a DHCPv4_control */
);

extern
int dhcp4_nic_callback
(   LIBDHCP_Control *control, /* must be a DHCPv4_control */
    DHCP_State state, 
    void *arg
);
