/* dhcp6_lease.h
 *
 *  Representation of DHCPv6 lease options for libdhcp
 *
 *  Copyright(C) Jason Vas Dias<jvdias@redhat.com> Red Hat Inc. May 2006
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation at 
 *           http://www.fsf.org/licensing/licenses/gpl.txt
 *  and included in this software distribution as the "LICENSE" file.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

#ifndef _DHCP6_LEASE_H
#define _DHCP6_LEASE_H

#include  <sys/types.h>
#include  <netinet/in.h>
#include  <stdint.h>

#include  <sys/queue.h>    /* glibc list macros */

enum dhcpv6_address_type_e
{
    DHCPv6_ADDRESS,
    DHCPv6_TEMPORARY_ADDRESS,
    DHCPv6_DELEGATED_PREFIX
}   DHCPv6_address_type;

typedef
struct dhcp6_lease_address_s
{
    struct in6_addr address;
    uint8_t         prefix_length;  
    uint8_t         type;
    uint16_t        status;
    time_t          time_acquired;
    time_t          valid_lifetime;
    time_t          prefer_lifetime;
    STAILQ_ENTRY    ( dhcp6_lease_address_s ) link;
}   DHCPv6_lease_address;

/*  There may be multiple DHCPv6 addresses per lease,
 *  each of which may have different prefix length,
 *  and lifetimes.
 */

typedef
STAILQ_HEAD( dhcp6_lease_address_list_s, dhcp6_lease_address_s ) 
DHCPv6_lease_address_list;

typedef
struct ipv6_address_s
{
    struct in6_addr address;
    STAILQ_ENTRY( ipv6_address_s ) link;
}   IPv6_address;

typedef 
STAILQ_HEAD( ipv6_address_list_s, ipv6_address_s )
IPv6_address_list;

typedef 
struct dhcp6_lease_s
{
    DHCPv6_lease_address_list addresses;
    time_t   renew_time;
    time_t   rebind_time;    
    char     *search_list;      /* dns domain name search list, if sent */
    IPv6_address_list dns;      /* domain name servers */ 
    char     *if_name;          /* interface name      */
    uint32_t  if_index;         /* interface index    */
    uint32_t iaid;  		/* DHCPv6 lease identifier */ 
    char     *client_duid;  	/* DHCPv6 client identifier */
    char     *server_duid;  	/* DHCPv6 server identifier */
    struct in6_addr server_address;  
} DHCPv6_lease;

struct dhcp6_optinfo;           /* defined in dhcpv6's dhcp6.h */

extern DHCPv6_lease *dhcpv6_lease ( struct dhcp6_optinfo * );
       /* call this with the dhcp6_optinfo * returned to the
	* libdhcp callback on the DHC6_BOUND state to construct
        * a DHCPv6_lease .
	*/
extern void dhcpv6_lease_free( DHCPv6_lease * );

#endif
