/* dhcp_nic.h
 *
 * Network Interface Configurator for BOTH the ISC DHCP IPv4 client library
 * and the DHCPv6 IPv6 client, API.
 *
 *  Copyright(C) Jason Vas Dias <jvdias@redhat.com> Red Hat Inc. May 2006
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation at 
 *           http://www.fsf.org/licensing/licenses/gpl.txt
 *  and included in this software distribution as the "LICENSE" file.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

#include <libdhcp.h>
#include <nic.h>
#include <dhcp4_nic.h>
#include <dhcp4_lease.h>
#include <dhcp6_nic.h>
#include <dhcp6_lease.h>
#include <malloc.h>

typedef
enum 
{
    DHCPv4_DISABLE  = 1,
    DHCPv6_DISABLE  = 2,
    IPv6_PREFERENCE = 4,  /* Configure IPv6 addresses / routes / DNS first */ 
    DHCPv4_DISABLE_ADDRESSES = 8,  /* Don't configure DHCPv4 addresses */
    DHCPv4_DISABLE_ROUTES    = 16, /* Don't configure DHCPv4 routes */
    DHCPv4_DISABLE_RESOLVER  = 32, /* Don't configure DHCPv4 resolv.conf entries */
    DHCPv6_DISABLE_ADDRESSES = 64, /* Don't configure DHCPv6 address (ie. use radvd) */
    DHCPv6_DISABLE_RESOLVER  = 128,/* Don't configure DHCPv6 resolv.conf entries */
    DHCPv4_DISABLE_HOSTNAME_SET=256/* Don't set hostname if DHCPv4 host-name option sent */ 
}   DHCP_Preference;


typedef
struct dhcpc_nic_s
{
    NLH_t          nh;
    NIC_t          nic;
    IPaddr_list_t  address_list;
    IProute_list_t route_list;
    IPaddr_list_t  dns_list;
    char          *search_list;
    char          *host_name;
    union 
    { 
	DHCPv4_lease  *dhcp4_lease;
	DHCPv6_lease  *dhcp6_lease;
    };
} DHCP_config;

typedef
struct dhcp_nic
{
    DHCPv4_control  *dhc4ctl;
    LIBDHCP_Control *dhc6ctl;
    NLH_t             nh;
    DHCP_config  *dhcpv4;
    DHCP_config  *dhcpv6;
    DHCP_Preference preference;
} DHCP_nic;

extern 
DHCP_nic *do_dhcp
( 
    DHCP_Preference preference,
    char                  *eth_if_name,
    LIBDHCP_Capability     dhc_cap, 
    time_t                 timeout,    
    LIBDHCP_Error_Handler  error_handler,
    uint8_t                log_level,
    ... /* extra DHCPv4 dhclient arguments;
	 * last arg MUST be 0 .
	 */
);

extern 
NIC_Res_t
dhcp_nic_configure
(
    DHCP_nic *dhcp_nic
);
